@@ -85,4 +85,4 @@ class App(AbstractApp, Generic[GenericAppDepContainer]):
         Func to run environment manually (without Runner)
         :return: None
         """
-        return await asyncio.wait(self.perform() + self.dispatcher.preform())
+        return await asyncio.wait(self.perform() + self.dispatcher.perform())
