@@ -4,6 +4,7 @@ from typing import Callable, Awaitable, Any
 from typing import List, TypeVar, Tuple, Generic
 
 from pydantic import BaseModel as PdModel
+from tortoise import Tortoise, connections
 from tortoise.exceptions import IntegrityError, FieldError
 from tortoise.queryset import QuerySet, MODEL
 
@@ -108,11 +109,17 @@ class ModelLoader(Generic[GenericDbType]):
         if offset:
             query = query.offset(offset)
         query = await cls.fetch_related(model, query, fetch_fields)
+        query = query.distinct()
         try:
             entities = await query
             query._limit = None
             query._offset = None
-            total = await query.count()
+            # --- todo something more flexible --- #
+            con = Tortoise.get_connection(connections.all()[0].connection_name)
+            query = str(query.sql()).replace('COUNT(*)', 'COUNT(DISTINCT ID)')
+            _, res = await con.execute_query(query)
+            total = res[0].get('count')
+            # ------------------------------------ #
         except FieldError:
             raise InconsistencyError(message="Incorrect filter")
         return entities, total
